@@ -1,3 +1,9 @@
+"""
+Scikit-build-core's nox configuration.
+
+Use `-t gen` to run all the generation jobs.
+"""
+
 from __future__ import annotations
 
 import argparse
@@ -11,7 +17,7 @@ import nox
 if TYPE_CHECKING:
     from collections.abc import Sequence
 
-nox.needs_version = ">=2024.3.2"
+nox.needs_version = ">=2024.4.15"
 nox.options.default_venv_backend = "uv|virtualenv"
 
 DIR = Path(__file__).parent.resolve()
@@ -48,6 +54,16 @@ def pylint(session: nox.Session) -> None:
     session.run("pylint", "scikit_build_core", *session.posargs)
 
 
+def _prepare_cmake_ninja(
+    session: nox.Session,
+) -> None:
+    # This will not work if system CMake is too old (<3.15)
+    if shutil.which("cmake") is None and shutil.which("cmake3") is None:
+        session.install("cmake")
+    if shutil.which("ninja") is None:
+        session.install("ninja")
+
+
 def _run_tests(
     session: nox.Session,
     *,
@@ -58,11 +74,7 @@ def _run_tests(
     posargs = list(session.posargs)
     env = {"PIP_DISABLE_PIP_VERSION_CHECK": "1"}
 
-    # This will not work if system CMake is too old (<3.15)
-    if shutil.which("cmake") is None and shutil.which("cmake3") is None:
-        session.install("cmake")
-    if shutil.which("ninja") is None:
-        session.install("ninja")
+    _prepare_cmake_ninja(session)
 
     _extras = ["test", *extras]
     if "--cov" in posargs:
@@ -70,12 +82,11 @@ def _run_tests(
         posargs.append("--cov-config=pyproject.toml")
 
     install_arg = f"-e.[{','.join(_extras)}]"
-    session.install(install_arg, *install_args)
-    session.run("pip", "list")
+    session.install(install_arg, *install_args, silent=False)
     session.run("pytest", *run_args, *posargs, env=env)
 
 
-@nox.session(reuse_venv=True)
+@nox.session(reuse_venv=True, tags=["gen"])
 def generate_schema(session: nox.Session) -> None:
     """
     (Re)generate src/scikit_build_core/resources/scikit-build.schema.json from model.
@@ -97,7 +108,7 @@ def tests(session: nox.Session) -> None:
     _run_tests(session, extras=["test-meta,test-numpy,test-schema,test-hatchling"])
 
 
-@nox.session(reuse_venv=True)
+@nox.session(reuse_venv=True, tags=["gen"])
 def readme(session: nox.Session) -> None:
     """
     Update the readme with cog. Pass --check to check instead.
@@ -109,14 +120,15 @@ def readme(session: nox.Session) -> None:
     session.run("cog", "-P", *args, "README.md")
 
 
-@nox.session
+@nox.session(venv_backend="uv")
 def minimums(session: nox.Session) -> None:
     """
     Test the minimum versions of dependencies.
     """
+
     _run_tests(
         session,
-        install_args=["--constraint=tests/constraints.txt"],
+        install_args=["--resolution=lowest-direct"],
         run_args=["-Wdefault"],
     )
 
@@ -154,7 +166,7 @@ def docs(session: nox.Session) -> None:
         session.run("sphinx-build", "--keep-going", *shared_args)
 
 
-@nox.session
+@nox.session(tags=["gen"])
 def build_api_docs(session: nox.Session) -> None:
     """
     Build (regenerate) API docs.
@@ -193,8 +205,17 @@ EXAMPLES += ["downstream/pybind11_example", "downstream/nanobind_example"]
 @nox.session
 @nox.parametrize("example", EXAMPLES, ids=EXAMPLES)
 def test_doc_examples(session: nox.Session, example: str) -> None:
+    _prepare_cmake_ninja(session)
+    session.install("-e.")
     session.chdir(f"docs/examples/{example}")
-    session.install(".", "--config-settings=cmake.verbose=true", "pytest")
+    reqs = nox.project.load_toml("pyproject.toml")["build-system"]["requires"]
+    session.install(*reqs, "pytest")
+    session.install(
+        ".",
+        "--no-build-isolation",
+        "--config-settings=cmake.verbose=true",
+        env={"PYTHONWARNINGS": "error"},
+    )
     if Path("../test.py").is_file():
         session.run("python", "../test.py")
     else:
@@ -224,6 +245,7 @@ def downstream(session: nox.Session) -> None:
         "--editable", action="store_true", help="Install as editable wheel"
     )
     parser.add_argument("-c", dest="code", help="Run some Python code")
+    parser.add_argument("-C", help="config-settings", action="append", default=[])
     args, remaining = parser.parse_known_args(session.posargs)
 
     tmp_dir = Path(session.create_tmp())
@@ -277,6 +299,7 @@ def downstream(session: nox.Session) -> None:
             "--skip-dependency-check",
             "--wheel",
             ".",
+            *(f"-C{x}" for x in args.C),
         )
         if args.code:
             session.error("Must use editable install for code at the moment")
