@@ -2,6 +2,7 @@ from __future__ import annotations
 
 import dataclasses
 import re
+import shlex
 import sys
 import sysconfig
 from pathlib import Path
@@ -28,7 +29,7 @@ if TYPE_CHECKING:
     from ..cmake import CMaker
     from ..settings.skbuild_model import ScikitBuildSettings
 
-__all__ = ["Builder", "get_archs", "archs_to_tags"]
+__all__ = ["Builder", "archs_to_tags", "get_archs"]
 
 DIR = Path(__file__).parent.resolve()
 
@@ -94,9 +95,10 @@ class Builder:
         """
         # Adding CMake arguments set as environment variable
         # (needed e.g. to build for ARM OSX on conda-forge)
-        env_cmake_args = list(
-            filter(None, self.config.env.get("CMAKE_ARGS", "").split(" "))
+        env_cmake_args: list[str] = list(
+            filter(None, shlex.split(self.config.env.get("CMAKE_ARGS", "")))
         )
+
         if env_cmake_args:
             logger.debug("Env CMAKE_ARGS: {}", env_cmake_args)
 
@@ -108,15 +110,15 @@ class Builder:
     def configure(
         self,
         *,
-        defines: Mapping[str, str | bool],
+        defines: Mapping[str, str | bool | Path],
         cache_entries: Mapping[str, str | Path] | None = None,
         name: str | None = None,
         version: Version | None = None,
-        limited_abi: bool | None = None,
+        limited_api: bool | None = None,
         configure_args: Iterable[str] = (),
     ) -> None:
         cmake_defines = {
-            k: ("TRUE" if v else "FALSE") if isinstance(v, bool) else v
+            k: ("TRUE" if v else "FALSE") if isinstance(v, bool) else str(v)
             for k, v in defines.items()
         }
 
@@ -157,18 +159,31 @@ class Builder:
             canonical_name = name.replace("-", "_").replace(".", "_")
             cache_config["SKBUILD_PROJECT_NAME"] = canonical_name
         if version is not None:
-            cache_config["SKBUILD_PROJECT_VERSION"] = str(version)
+            cache_config["SKBUILD_PROJECT_VERSION"] = ".".join(
+                str(v) for v in version.release
+            )
+            cache_config["SKBUILD_PROJECT_VERSION_FULL"] = str(version)
 
-        if limited_abi is None:
+        if limited_api is None:
             if self.settings.wheel.py_api.startswith("cp3"):
                 target_minor_version = int(self.settings.wheel.py_api[3:])
-                limited_abi = target_minor_version <= sys.version_info.minor
+                limited_api = target_minor_version <= sys.version_info.minor
             else:
-                limited_abi = False
+                limited_api = False
+
+        if limited_api and sys.implementation.name != "cpython":
+            limited_api = False
+            logger.info("PyPy doesn't support the Limited API, ignoring")
+
+        if limited_api and sysconfig.get_config_var("Py_GIL_DISABLED"):
+            limited_api = False
+            logger.info(
+                "Free-threaded Python doesn't support the Limited API currently, ignoring"
+            )
 
         python_library = get_python_library(self.config.env, abi3=False)
         python_sabi_library = (
-            get_python_library(self.config.env, abi3=True) if limited_abi else None
+            get_python_library(self.config.env, abi3=True) if limited_api else None
         )
         python_include_dir = get_python_include_dir()
         numpy_include_dir = get_numpy_include_dir()
@@ -193,11 +208,11 @@ class Builder:
             if numpy_include_dir:
                 cache_config[f"{prefix}_NumPy_INCLUDE_DIR"] = numpy_include_dir
 
-        cache_config["SKBUILD_SOABI"] = get_soabi(self.config.env, abi3=limited_abi)
+        cache_config["SKBUILD_SOABI"] = get_soabi(self.config.env, abi3=limited_api)
 
         # Allow CMakeLists to detect this is supposed to be a limited ABI build
         cache_config["SKBUILD_SABI_COMPONENT"] = (
-            "Development.SABIModule" if limited_abi else ""
+            "Development.SABIModule" if limited_api else ""
         )
 
         if cache_entries:
@@ -224,14 +239,25 @@ class Builder:
             cmake_args=[*self.get_cmake_args(), *configure_args],
         )
 
-    def build(self, build_args: list[str]) -> None:
+    def build(self, build_args: Sequence[str]) -> None:
+        build_tool_args = self.settings.build.tool_args
+        if build_tool_args:
+            build_args = [*build_args, "--", *build_tool_args]
+
         self.config.build(
             build_args=build_args,
-            targets=self.settings.cmake.targets,
-            verbose=self.settings.cmake.verbose,
+            targets=self.settings.build.targets,
+            verbose=self.settings.build.verbose,
         )
 
-    def install(self, install_dir: Path) -> None:
+    def install(self, install_dir: Path | None) -> None:
+        """
+        Install to a path.
+
+        Warning: if a package hard-codes CMAKE_INSTALL_PREFIX in the install
+        commands, this will not rewrite those; set that variable when
+        configuring for maximum compatibility.
+        """
         components = self.settings.install.components
         strip = self.settings.install.strip
         assert strip is not None
