@@ -2,20 +2,23 @@ import dataclasses
 from pathlib import Path
 from typing import Any, Dict, List, Optional, Union
 
+from packaging.specifiers import SpecifierSet
 from packaging.version import Version
 
-from .._compat.typing import Literal
+from .._compat.typing import Annotated, Literal
 
 __all__ = [
     "BackportSettings",
+    "BuildSettings",
     "CMakeSettings",
     "EditableSettings",
+    "GenerateSettings",
     "InstallSettings",
     "LoggingSettings",
+    "MessagesSettings",
     "NinjaSettings",
     "SDistSettings",
     "ScikitBuildSettings",
-    "GenerateSettings",
     "WheelSettings",
 ]
 
@@ -26,11 +29,18 @@ def __dir__() -> List[str]:
 
 @dataclasses.dataclass
 class CMakeSettings:
-    minimum_version: Version = Version("3.15")
+    minimum_version: Optional[Version] = None
     """
-    The minimum version of CMake to use. If CMake is not present on the system
-    or is older than this, it will be downloaded via PyPI if possible. An empty
-    string will disable this check.
+    DEPRECATED in 0.8; use version instead.
+    """
+
+    version: Optional[SpecifierSet] = None
+    """
+    The versions of CMake to allow. If CMake is not present on the system or
+    does not pass this specifier, it will be downloaded via PyPI if possible. An
+    empty string will disable this check. The default on 0.10+ is
+    "CMakeLists.txt", which will read it from the project's CMakeLists.txt file,
+    or ">=3.15" if unreadable or <0.10.
     """
 
     args: List[str] = dataclasses.field(default_factory=list)
@@ -39,14 +49,16 @@ class CMakeSettings:
     in config or envvar will override toml. See also ``cmake.define``.
     """
 
-    define: Dict[str, Union[str, bool]] = dataclasses.field(default_factory=dict)
+    define: Annotated[Dict[str, Union[str, bool]], "EnvVar"] = dataclasses.field(
+        default_factory=dict
+    )
     """
     A table of defines to pass to CMake when configuring the project. Additive.
     """
 
-    verbose: bool = False
+    verbose: Optional[bool] = None
     """
-    Verbose printout when building.
+    DEPRECATED in 0.10, use build.verbose instead.
     """
 
     build_type: str = "Release"
@@ -62,34 +74,38 @@ class CMakeSettings:
     affects the native builder (not the setuptools plugin).
     """
 
-    targets: List[str] = dataclasses.field(default_factory=list)
+    targets: Optional[List[str]] = None
     """
-    The build targets to use when building the project. Empty builds the
-    default target.
+    DEPRECATED in 0.10; use build.targets instead.
     """
 
 
 @dataclasses.dataclass
 class NinjaSettings:
-    minimum_version: Version = Version("1.5")
+    minimum_version: Optional[Version] = None
     """
-    The minimum version of Ninja to use. If Ninja is not present on the system
-    or is older than this, it will be downloaded via PyPI if possible. An empty
+    DEPRECATED in 0.8; use version instead.
+    """
+
+    version: SpecifierSet = SpecifierSet(">=1.5")
+    """
+    The versions of Ninja to allow. If Ninja is not present on the system or does
+    not pass this specifier, it will be downloaded via PyPI if possible. An empty
     string will disable this check.
     """
 
     make_fallback: bool = True
     """
-    If CMake is not present on the system or is older required, it will be
-    downloaded via PyPI if possible. An empty string will disable this check.
+    If Ninja is not present on the system or is older than required,
+    it will be downloaded via PyPI if this is false.
     """
 
 
 @dataclasses.dataclass
 class LoggingSettings:
-    level: Literal[
-        "NOTSET", "DEBUG", "INFO", "WARNING", "ERROR", "CRITICAL"
-    ] = "WARNING"
+    level: Literal["NOTSET", "DEBUG", "INFO", "WARNING", "ERROR", "CRITICAL"] = (
+        "WARNING"
+    )
     """
     The logging level to display, "DEBUG", "INFO", "WARNING", and "ERROR" are
     possible options.
@@ -126,12 +142,13 @@ class SDistSettings:
 
 @dataclasses.dataclass
 class WheelSettings:
-    packages: Optional[List[str]] = None
+    packages: Optional[Union[List[str], Dict[str, str]]] = None
     """
     A list of packages to auto-copy into the wheel. If this is not set, it will
     default to the first of ``src/<package>``, ``python/<package>``, or
     ``<package>`` if they exist.  The prefix(s) will be stripped from the
-    package name inside the wheel.
+    package name inside the wheel. If a dict, provides a mapping of package
+    name to source directory.
     """
 
     py_api: str = ""
@@ -180,8 +197,14 @@ class WheelSettings:
     exclude: List[str] = dataclasses.field(default_factory=list)
     """
     A set of patterns to exclude from the wheel. This is additive to the SDist
-    exclude patterns. This applies to the source files, not the final paths.
-    Editable installs may not respect this exclusion.
+    exclude patterns. This applies to the final paths in the wheel, and can
+    exclude files from CMake output as well.  Editable installs may not respect
+    this exclusion.
+    """
+
+    build_tag: str = ""
+    """
+    The build tag to use for the wheel. If empty, no build tag is used.
     """
 
 
@@ -213,6 +236,25 @@ class EditableSettings:
     """
 
 
+@dataclasses.dataclass
+class BuildSettings:
+    tool_args: List[str] = dataclasses.field(default_factory=list)
+    """
+    Extra args to pass directly to the builder in the build step.
+    """
+
+    targets: List[str] = dataclasses.field(default_factory=list)
+    """
+    The build targets to use when building the project. Empty builds the
+    default target.
+    """
+
+    verbose: bool = False
+    """
+    Verbose printout when building.
+    """
+
+
 @dataclasses.dataclass
 class InstallSettings:
     components: List[str] = dataclasses.field(default_factory=list)
@@ -253,6 +295,23 @@ class GenerateSettings:
     """
 
 
+@dataclasses.dataclass
+class MessagesSettings:
+    """
+    Settings for messages.
+    """
+
+    after_failure: str = ""
+    """
+    A message to print after a build failure.
+    """
+
+    after_success: str = ""
+    """
+    A message to print after a successful build.
+    """
+
+
 @dataclasses.dataclass
 class ScikitBuildSettings:
     cmake: CMakeSettings = dataclasses.field(default_factory=CMakeSettings)
@@ -262,8 +321,10 @@ class ScikitBuildSettings:
     wheel: WheelSettings = dataclasses.field(default_factory=WheelSettings)
     backport: BackportSettings = dataclasses.field(default_factory=BackportSettings)
     editable: EditableSettings = dataclasses.field(default_factory=EditableSettings)
+    build: BuildSettings = dataclasses.field(default_factory=BuildSettings)
     install: InstallSettings = dataclasses.field(default_factory=InstallSettings)
     generate: List[GenerateSettings] = dataclasses.field(default_factory=list)
+    messages: MessagesSettings = dataclasses.field(default_factory=MessagesSettings)
 
     metadata: Dict[str, Dict[str, Any]] = dataclasses.field(default_factory=dict)
     """
@@ -290,3 +351,8 @@ class ScikitBuildSettings:
     """
     The build directory. Defaults to a temporary directory, but can be set.
     """
+
+    fail: bool = False
+    """
+    Immediately fail the build. This is only useful in overrides.
+    """
