@@ -9,6 +9,7 @@ import setuptools
 import setuptools.errors
 from packaging.version import Version
 
+from .._logging import LEVEL_VALUE, raw_logger
 from ..builder.builder import Builder, get_archs
 from ..builder.macos import normalize_macos_version
 from ..cmake import CMake, CMaker
@@ -18,17 +19,21 @@ if TYPE_CHECKING:
     from setuptools.dist import Distribution
 
     from .._compat.typing import Literal
+    from ..settings.skbuild_model import ScikitBuildSettings
 
-__all__ = ["BuildCMake", "finalize_distribution_options", "cmake_source_dir"]
+__all__ = [
+    "BuildCMake",
+    "cmake_args",
+    "cmake_source_dir",
+    "finalize_distribution_options",
+]
 
 
 def __dir__() -> list[str]:
     return __all__
 
 
-def _validate_settings() -> None:
-    settings = SettingsReader.from_file("pyproject.toml", {}).settings
-
+def _validate_settings(settings: ScikitBuildSettings) -> None:
     assert (
         not settings.wheel.expand_macos_universal_tags
     ), "wheel.expand_macos_universal_tags is not supported in setuptools mode"
@@ -89,7 +94,8 @@ class BuildCMake(setuptools.Command):
         assert self.build_temp is not None
         assert self.plat_name is not None
 
-        _validate_settings()
+        settings = SettingsReader.from_file("pyproject.toml").settings
+        _validate_settings(settings)
 
         build_tmp_folder = Path(self.build_temp)
         build_temp = build_tmp_folder / "_skbuild"  # TODO: include python platform
@@ -112,9 +118,7 @@ class BuildCMake(setuptools.Command):
         if build_temp.exists():
             shutil.rmtree(build_temp)
 
-        settings = SettingsReader.from_file("pyproject.toml", {}).settings
-
-        cmake = CMake.default_search(minimum_version=settings.cmake.minimum_version)
+        cmake = CMake.default_search(version=settings.cmake.version)
 
         config = CMaker(
             cmake,
@@ -137,11 +141,16 @@ class BuildCMake(setuptools.Command):
 
         builder.config.build_type = "Debug" if self.debug else settings.cmake.build_type
 
+        # Setting the install prefix because some libs hardcode CMAKE_INSTALL_PREFIX
+        # Otherwise `cmake --install --prefix` would work by itself
+        install_dir = Path(self.build_lib)
+        defines = {"CMAKE_INSTALL_PREFIX": install_dir}
+
         builder.configure(
             name=dist.get_name(),
             version=Version(dist.get_version()),
-            defines={},
-            limited_abi=limited_api,
+            defines=defines,
+            limited_api=limited_api,
             configure_args=configure_args,
         )
 
@@ -155,7 +164,7 @@ class BuildCMake(setuptools.Command):
             build_args.append(f"-j{self.parallel}")
 
         builder.build(build_args=build_args)
-        builder.install(Path(self.build_lib))
+        builder.install(install_dir=install_dir)
 
     # def "get_source_file+ys"(self) -> list[str]:
     #    return ["CMakeLists.txt"]
@@ -176,9 +185,26 @@ def _has_cmake(dist: Distribution) -> bool:
     )
 
 
-def _prepare_extension_detection(dist: Distribution) -> None:
-    # Setuptools needs to know that it has extensions modules
+def finalize_distribution_options(dist: Distribution) -> None:
+    # Prepare new build_cmake command and make sure build calls it
+    build = dist.get_command_class("build")
+    assert build is not None
+    if "build_cmake" not in {x for x, _ in build.sub_commands}:
+        build.sub_commands.append(
+            ("build_cmake", lambda cmd: _has_cmake(cmd.distribution))
+        )
 
+
+def _cmake_extension(dist: Distribution) -> None:
+    # Every keyword argument needs to call this
+    # Run this only once
+    if getattr(dist, "_has_cmake_extensions", False):
+        return
+
+    # pylint: disable-next=protected-access
+    dist._has_cmake_extensions = True  # type: ignore[attr-defined]
+
+    # Setuptools needs to know that it has extensions modules
     orig_has_ext_modules = dist.has_ext_modules
     dist.has_ext_modules = lambda: orig_has_ext_modules() or _has_cmake(dist)  # type: ignore[method-assign]
 
@@ -191,35 +217,27 @@ def _prepare_extension_detection(dist: Distribution) -> None:
 
         dist.ext_modules = getattr(dist, "ext_modules", []) or EvilList()
 
-
-def _prepare_build_cmake_command(dist: Distribution) -> None:
-    # Prepare new build_cmake command and make sure build calls it
-    build = dist.get_command_class("build")
-    assert build is not None
-    if "build_cmake" not in {x for x, _ in build.sub_commands}:
-        build.sub_commands.append(
-            ("build_cmake", lambda cmd: _has_cmake(cmd.distribution))  # type: ignore[arg-type]
-        )
+    # Setup logging
+    settings = SettingsReader.from_file("pyproject.toml").settings
+    level_value = LEVEL_VALUE[settings.logging.level]
+    raw_logger.setLevel(level_value)
 
 
 def cmake_args(
-    _dist: Distribution, attr: Literal["cmake_args"], value: list[str]
+    dist: Distribution, attr: Literal["cmake_args"], value: list[str]
 ) -> None:
     assert attr == "cmake_args"
+    _cmake_extension(dist)
     if not isinstance(value, list):
         msg = "cmake_args must be a list"
         raise setuptools.errors.SetupError(msg)
 
 
 def cmake_source_dir(
-    _dist: Distribution, attr: Literal["cmake_source_dir"], value: str
+    dist: Distribution, attr: Literal["cmake_source_dir"], value: str
 ) -> None:
     assert attr == "cmake_source_dir"
+    _cmake_extension(dist)
     if not Path(value).is_dir():
         msg = "cmake_source_dir must be an existing directory"
         raise setuptools.errors.SetupError(msg)
-
-
-def finalize_distribution_options(dist: Distribution) -> None:
-    _prepare_extension_detection(dist)
-    _prepare_build_cmake_command(dist)
