@@ -9,6 +9,7 @@ import subprocess
 import sys
 import sysconfig
 from pathlib import Path
+from typing import Any
 
 import virtualenv as _virtualenv
 
@@ -52,8 +53,7 @@ def pep518_wheelhouse(tmp_path_factory: pytest.TempPathFactory) -> Path:
         "build",
         "cython",
         "hatchling",
-        "pip>=23; python_version<'3.13'",
-        "pip>=24.1b1; python_version>='3.13'",
+        "pip",
         "pybind11",
         "setuptools",
         "virtualenv",
@@ -96,7 +96,7 @@ class VEnv:
             self.execute("import sysconfig; print(sysconfig.get_path('purelib'))")
         )
         if sys.version_info >= (3, 13):
-            self.run("pip", "install", "-U", "pip>=24.1b1")
+            self.run("pip", "install", "-U", "pip>=24.1")
 
     @overload
     def run(self, *args: str, capture: Literal[True]) -> str: ...
@@ -303,6 +303,15 @@ def navigate_editable(tmp_path: Path, monkeypatch: pytest.MonkeyPatch) -> Packag
     return package
 
 
+@pytest.fixture()
+def broken_fallback(tmp_path: Path, monkeypatch: pytest.MonkeyPatch) -> PackageInfo:
+    package = PackageInfo(
+        "broken_fallback",
+    )
+    process_package(package, tmp_path, monkeypatch)
+    return package
+
+
 @pytest.fixture()
 def package_sdist_config(
     tmp_path: Path, monkeypatch: pytest.MonkeyPatch
@@ -325,6 +334,34 @@ def package_simple_purelib_package(
     return package
 
 
+def which_mock(name: str) -> str | None:
+    if name in {"ninja", "ninja-build", "cmake3", "samu", "gmake", "make"}:
+        return None
+    if name == "cmake":
+        return "cmake/path"
+    return None
+
+
+@pytest.fixture()
+def protect_get_requires(fp, monkeypatch):
+    """
+    Protect get_requires from actually calling anything variable during tests.
+    """
+    # This needs to be passed due to packaging.tags 22 extra checks if macos 10.16 is reported
+    fp.pass_command([sys.executable, fp.any()])
+    monkeypatch.setattr(shutil, "which", which_mock)
+    monkeypatch.delenv("CMAKE_GENERATOR", raising=False)
+
+    orig_find_spec = importlib.util.find_spec
+
+    def find_spec(name: str, package: str | None = None) -> Any:
+        if name in {"cmake", "ninja"}:
+            return None
+        return orig_find_spec(name, package)
+
+    monkeypatch.setattr(importlib.util, "find_spec", find_spec)
+
+
 def pytest_collection_modifyitems(items: list[pytest.Item]) -> None:
     for item in items:
         # Ensure all tests using virtualenv are marked as such
