@@ -134,12 +134,13 @@ def test_navigate_editable_pkg(editable_package: EditablePackage, virtualenv: VE
     site_packages, pkg_dir, src_pkg_dir = editable_package
 
     # Create a fake editable install
-    packages = ["pkg"]
+    packages = {"pkg": "pkg"}
     mapping = packages_to_file_mapping(
         packages=packages,
         platlib_dir=site_packages,
         include=[],
-        exclude=[],
+        src_exclude=[],
+        target_exclude=[],
     )
     assert mapping == {
         str(Path("pkg/__init__.py")): str(pkg_dir / "__init__.py"),
