@@ -1,14 +1,25 @@
 from __future__ import annotations
 
+import sysconfig
 import typing
+from pathlib import Path
 from textwrap import dedent
 
 import pytest
 
-from scikit_build_core.settings.skbuild_read_settings import SettingsReader, regex_match
+import scikit_build_core.settings.skbuild_overrides
+from scikit_build_core.settings.skbuild_overrides import regex_match
+from scikit_build_core.settings.skbuild_read_settings import SettingsReader
 
 if typing.TYPE_CHECKING:
-    from pathlib import Path
+    from pytest_subprocess import FakeProcess
+
+
+class VersionInfo(typing.NamedTuple):
+    major: int
+    minor: int
+    micro: int
+    releaselevel: str = "final"
 
 
 @pytest.mark.parametrize("python_version", ["3.9", "3.10"])
@@ -43,7 +54,37 @@ def test_skbuild_overrides_pyver(
         assert not settings.cmake.args
         assert not settings.cmake.define
         assert not settings.experimental
-        assert not settings.sdist.cmake
+
+
+@pytest.mark.parametrize("implementation_version", ["7.3.14", "7.3.15"])
+def test_skbuild_overrides_implver(
+    implementation_version: str, tmp_path: Path, monkeypatch: pytest.MonkeyPatch
+):
+    monkeypatch.setattr("sys.implementation.name", "pypy")
+    monkeypatch.setattr(
+        "sys.implementation.version",
+        VersionInfo(*(int(x) for x in implementation_version.split("."))),  # type: ignore[arg-type]
+    )
+    pyproject_toml = tmp_path / "pyproject.toml"
+    pyproject_toml.write_text(
+        dedent(
+            """\
+            [[tool.scikit-build.overrides]]
+            if.implementation-name = "pypy"
+            if.implementation-version = ">=7.3.15"
+            experimental = true
+            """
+        ),
+        encoding="utf-8",
+    )
+
+    settings_reader = SettingsReader.from_file(pyproject_toml)
+    settings = settings_reader.settings
+
+    if implementation_version == "7.3.15":
+        assert settings.experimental
+    else:
+        assert not settings.experimental
 
 
 @pytest.mark.parametrize("implementation_name", ["cpython", "pypy"])
@@ -79,6 +120,7 @@ def test_skbuild_overrides_dual(
 
     settings_reader = SettingsReader.from_file(pyproject_toml)
     settings = settings_reader.settings
+    print(settings_reader.overrides)
 
     if implementation_name == "pypy" and platform_system == "darwin":
         assert not settings.editable.verbose
@@ -490,3 +532,324 @@ def test_skbuild_overrides_inherit(inherit: str, tmp_path: Path):
         assert settings.wheel.exclude == ["xx", "yy", "x", "y"]
         assert settings.install.components == ["c", "d", "a", "b"]
         assert settings.cmake.define == {"a": "A", "b": "B", "c": "C"}
+
+
+@pytest.mark.parametrize("from_sdist", [True, False])
+def test_skbuild_overrides_from_sdist(
+    tmp_path: Path, monkeypatch: pytest.MonkeyPatch, from_sdist: bool
+):
+    pyproject_toml = (
+        tmp_path / ("from_sdist" if from_sdist else "not_from_sdist") / "pyproject.toml"
+    )
+    pyproject_toml.parent.mkdir(exist_ok=True)
+
+    pyproject_toml.write_text(
+        dedent(
+            """\
+            [tool.scikit-build]
+            cmake.version = ">=3.15"
+            wheel.cmake = false
+            sdist.cmake = false
+
+            [[tool.scikit-build.overrides]]
+            if.from-sdist = false
+            wheel.cmake = true
+
+            [[tool.scikit-build.overrides]]
+            if.from-sdist = true
+            sdist.cmake = true
+            """
+        ),
+        encoding="utf-8",
+    )
+
+    if from_sdist:
+        pyproject_toml.parent.joinpath("PKG-INFO").touch(exist_ok=True)
+
+    monkeypatch.chdir(pyproject_toml.parent)
+
+    settings_reader = SettingsReader.from_file(pyproject_toml, state="wheel")
+    settings = settings_reader.settings
+
+    assert settings.wheel.cmake != from_sdist
+    assert settings.sdist.cmake == from_sdist
+
+
+def test_failed_retry(tmp_path: Path, monkeypatch: pytest.MonkeyPatch) -> None:
+    pyproject_toml = tmp_path / "pyproject.toml"
+    pyproject_toml.write_text(
+        dedent(
+            """\
+            [tool.scikit-build]
+            wheel.cmake = false
+            sdist.cmake = false
+
+            [[tool.scikit-build.overrides]]
+            if.failed = true
+            wheel.cmake = true
+
+            [[tool.scikit-build.overrides]]
+            if.failed = false
+            sdist.cmake = true
+            """
+        ),
+        encoding="utf-8",
+    )
+
+    monkeypatch.chdir(tmp_path)
+
+    settings_reader = SettingsReader.from_file(pyproject_toml, retry=False)
+    settings = settings_reader.settings
+    assert not settings.wheel.cmake
+    assert settings.sdist.cmake
+
+    settings_reader = SettingsReader.from_file(pyproject_toml, retry=True)
+    settings = settings_reader.settings
+    assert settings.wheel.cmake
+    assert not settings.sdist.cmake
+
+
+@pytest.mark.parametrize("sys_tag", ["win32", "linux"])
+def test_wheel_platform(tmp_path: Path, monkeypatch: pytest.MonkeyPatch, sys_tag: str):
+    pyproject_toml = tmp_path / "pyproject.toml"
+    pyproject_toml.write_text(
+        dedent(
+            """\
+            [tool.scikit-build]
+            wheel.cmake = false
+
+            [[tool.scikit-build.overrides]]
+            if.cmake-wheel = true
+            wheel.cmake = true
+            """
+        ),
+        encoding="utf-8",
+    )
+
+    monkeypatch.chdir(tmp_path)
+
+    monkeypatch.setattr("packaging.tags.sys_tags", lambda: [sys_tag])
+
+    settings_reader = SettingsReader.from_file(pyproject_toml, retry=False)
+    settings = settings_reader.settings
+    assert settings.wheel.cmake == (sys_tag == "win32")
+
+
+@pytest.mark.parametrize("cmake_version", ["3.21", "3.27"])
+@pytest.mark.usefixtures("protect_get_requires")
+def test_system_cmake(
+    tmp_path: Path,
+    monkeypatch: pytest.MonkeyPatch,
+    cmake_version: str | None,
+    fp: FakeProcess,
+) -> None:
+    if cmake_version:
+        fp.register(
+            [Path("cmake/path"), "-E", "capabilities"],
+            stdout=f'{{"version":{{"string": "{cmake_version}"}}}}',
+        )
+
+    pyproject_toml = tmp_path / "pyproject.toml"
+    pyproject_toml.write_text(
+        dedent(
+            """\
+            [tool.scikit-build]
+            wheel.cmake = false
+
+            [[tool.scikit-build.overrides]]
+            if.system-cmake = ">=3.24"
+            wheel.cmake = true
+            """
+        ),
+        encoding="utf-8",
+    )
+
+    monkeypatch.chdir(tmp_path)
+
+    settings_reader = SettingsReader.from_file(pyproject_toml, retry=False)
+    settings = settings_reader.settings
+    assert settings.wheel.cmake == (cmake_version == "3.27")
+
+
+def test_free_threaded_override(tmp_path: Path):
+    pyproject_toml = tmp_path / "pyproject.toml"
+    pyproject_toml.write_text(
+        dedent(
+            """\
+            [tool.scikit-build]
+            wheel.cmake = false
+
+            [[tool.scikit-build.overrides]]
+            if.abi-flags = "t"
+            wheel.cmake = true
+            """
+        )
+    )
+
+    settings_reader = SettingsReader.from_file(pyproject_toml, state="wheel")
+    settings = settings_reader.settings
+    assert settings.wheel.cmake == bool(sysconfig.get_config_var("Py_GIL_DISABLED"))
+
+
+@pytest.mark.parametrize("version", ["0.9", "0.10"])
+def test_skbuild_overrides_version(
+    tmp_path: Path, monkeypatch: pytest.MonkeyPatch, version: str
+):
+    monkeypatch.setattr(
+        scikit_build_core.settings.skbuild_overrides, "__version__", version
+    )
+    pyproject_toml = tmp_path / "pyproject.toml"
+    pyproject_toml.write_text(
+        dedent(
+            """\
+            [tool.scikit-build]
+            wheel.cmake = false
+
+            [[tool.scikit-build.overrides]]
+            if.scikit-build-version = ">=0.10"
+            wheel.cmake = true
+            """
+        )
+    )
+
+    settings_reader = SettingsReader.from_file(pyproject_toml, state="wheel")
+    settings = settings_reader.settings
+    if version == "0.10":
+        assert settings.wheel.cmake
+    else:
+        assert not settings.wheel.cmake
+
+
+def test_skbuild_overrides_unmatched_version(
+    tmp_path: Path, monkeypatch: pytest.MonkeyPatch
+):
+    monkeypatch.setattr(
+        scikit_build_core.settings.skbuild_overrides, "__version__", "0.10"
+    )
+    pyproject_toml = tmp_path / "pyproject.toml"
+    pyproject_toml.write_text(
+        dedent(
+            """\
+            [[tool.scikit-build.overrides]]
+            if.scikit-build-version = "<0.10"
+            if.is-not-real = true
+            also-not-real = true
+            """
+        )
+    )
+
+    settings = SettingsReader.from_file(pyproject_toml)
+    settings.validate_may_exit()
+
+
+def test_skbuild_overrides_matched_version_if(
+    tmp_path: Path, monkeypatch: pytest.MonkeyPatch
+):
+    monkeypatch.setattr(
+        scikit_build_core.settings.skbuild_overrides, "__version__", "0.10"
+    )
+    pyproject_toml = tmp_path / "pyproject.toml"
+    pyproject_toml.write_text(
+        dedent(
+            """\
+            [[tool.scikit-build.overrides]]
+            if.scikit-build-version = ">=0.10"
+            if.is-not-real = true
+            """
+        )
+    )
+
+    with pytest.raises(TypeError, match="is_not_real"):
+        SettingsReader.from_file(pyproject_toml)
+
+
+def test_skbuild_overrides_matched_version_extra(
+    tmp_path: Path, monkeypatch: pytest.MonkeyPatch, capsys: pytest.CaptureFixture[str]
+):
+    monkeypatch.setattr(
+        scikit_build_core.settings.skbuild_overrides, "__version__", "0.10"
+    )
+    pyproject_toml = tmp_path / "pyproject.toml"
+    pyproject_toml.write_text(
+        dedent(
+            """\
+            [[tool.scikit-build.overrides]]
+            if.scikit-build-version = ">=0.10"
+            not-real = true
+            """
+        )
+    )
+
+    settings = SettingsReader.from_file(pyproject_toml)
+    with pytest.raises(SystemExit):
+        settings.validate_may_exit()
+
+    assert "not-real" in capsys.readouterr().out
+
+
+def test_skbuild_overrides_matched_version_if_any(
+    tmp_path: Path, monkeypatch: pytest.MonkeyPatch
+):
+    monkeypatch.setattr(
+        scikit_build_core.settings.skbuild_overrides, "__version__", "0.9"
+    )
+    pyproject_toml = tmp_path / "pyproject.toml"
+    pyproject_toml.write_text(
+        dedent(
+            """\
+            [[tool.scikit-build.overrides]]
+            if.any.scikit-build-version = ">=0.10"
+            if.any.not-real = true
+            also-not-real = true
+            """
+        )
+    )
+
+    settings = SettingsReader.from_file(pyproject_toml)
+    settings.validate_may_exit()
+
+
+def test_skbuild_overrides_matched_version_if_any_dual(
+    tmp_path: Path, monkeypatch: pytest.MonkeyPatch
+):
+    monkeypatch.setattr(
+        scikit_build_core.settings.skbuild_overrides, "__version__", "0.9"
+    )
+    pyproject_toml = tmp_path / "pyproject.toml"
+    pyproject_toml.write_text(
+        dedent(
+            """\
+            [[tool.scikit-build.overrides]]
+            if.scikit-build-version = ">=0.10"
+            if.any.not-real = true
+            if.any.python-version = ">=3.7"
+            also-not-real = true
+            """
+        )
+    )
+
+    settings = SettingsReader.from_file(pyproject_toml)
+    settings.validate_may_exit()
+
+
+def test_skbuild_overrides_matched_version_if_any_match(
+    tmp_path: Path, monkeypatch: pytest.MonkeyPatch
+):
+    monkeypatch.setattr(
+        scikit_build_core.settings.skbuild_overrides, "__version__", "0.10"
+    )
+    pyproject_toml = tmp_path / "pyproject.toml"
+    pyproject_toml.write_text(
+        dedent(
+            """\
+            [[tool.scikit-build.overrides]]
+            if.any.scikit-build-version = ">=0.10"
+            if.any.not-real = true
+            if.python-version = ">=3.7"
+            experimental = true
+            """
+        )
+    )
+
+    with pytest.raises(TypeError, match="not_real"):
+        SettingsReader.from_file(pyproject_toml)
